@@ -12,6 +12,7 @@ from pyVmomi import vim, vmodl
 from pyVim.connect import Disconnect, SmartConnectNoSSL
 from infi.pyvmomi_wrapper.esxcli import EsxCLI
 from zabbix_api import ZabbixAPIException
+from lib.utils.inventory_tag import InventoryTagDict
 
 parser = argparse.ArgumentParser("Correct discoverd host name")
 parser.add_argument('-l', '--limit', action='append', type=str, help="Specify hypervisors")
@@ -70,48 +71,50 @@ def fetch_esxi(host, user, pwd, esxi_name, port=443):
     for esxi_ in container.view:
         if esxi_.name != esxi_name:
             continue
+        cpu = '(%s) * %s  %s核  %s线程' % (esxi_.summary.hardware.cpuModel,
+                           esxi_.summary.hardware.numCpuPkgs,
+                           esxi_.summary.hardware.numCpuCores,
+                           esxi_.summary.hardware.numCpuThreads)
+        mem = f'内存: {esxi_.summary.hardware.memorySize/1024/1024//1024}GB'
         esxi_info['type'] = 'Server'
         esxi_info['name'] = esxi_.name
         esxi_info['os'] = esxi_.config.product.name
         esxi_info['os_full'] = esxi_.summary.config.product.fullName
         esxi_info['os_short'] = esxi_.config.product.osType
-        esxi_info['tag'] = 'Esxi'
         esxi_info['model'] = esxi_.summary.hardware.model
         esxi_info['vendor'] = esxi_.summary.hardware.vendor
-        esxi_info['management_ip'] = esxi_.summary.managementServerIp
-        esxi_info['cpu'] = '(%s) * %s  %s核  %s线程' % (esxi_.summary.hardware.cpuModel,
-                           esxi_.summary.hardware.numCpuPkgs,
-                           esxi_.summary.hardware.numCpuCores,
-                           esxi_.summary.hardware.numCpuThreads)
-        esxi_info['mem'] = f'内存: {esxi_.summary.hardware.memorySize/1024/1024//1024}GB'
+        #esxi_info['management_ip'] = esxi_.summary.managementServerIp
+        esxi_info['hardware_full'] = '\n'.join([cpu, mem])
 
         # get host's ipA and netmask
         for vnic in esxi_.config.network.vnic:
             if isinstance(vnic, vim.host.VirtualNic):
-                esxi_info['ip'] = vnic.spec.ip.ipAddress
-                esxi_info['subnet_mask'] = vnic.spec.ip.subnetMask
+                esxi_info['host_networks'] = vnic.spec.ip.ipAddress
+                esxi_info['alias'] = vnic.spec.ip.ipAddress
+                esxi_info['host_netmask'] = vnic.spec.ip.subnetMask
 
         # get host's mac address
         for portgroup in esxi_.config.network.portgroup:
             for port in portgroup.port:
                 if port.type == 'host':
-                    esxi_info['mac_address'] = ''.join(port.mac)
+                    esxi_info['macaddress_a'] = ''.join(port.mac)
 
         # get host's serial_number
         ordered_keys = ['SerialNumberTag', 'EnclosureSerialNumberTag', 'ServiceTag']
+        sn_info = {}
         for iden in esxi_.summary.hardware.otherIdentifyingInfo:
             if isinstance(iden, vim.host.SystemIdentificationInfo) and iden.identifierType.key in ordered_keys:
-                esxi_info[iden.identifierType.key] = iden.identifierValue
+                sn_info[iden.identifierType.key] = iden.identifierValue
 
         for key in ordered_keys:
-            if esxi_info.get(key):
-                esxi_info['serial_number'] = esxi_info.get(key)
+            if sn_info.get(key):
+                esxi_info['serialno_a'] = sn_info.get(key)
                 break
 
-        if not esxi_info.get('serial_number'):
+        if not esxi_info.get('serialno_a'):
             cli = EsxCLI(esxi_)
             hardware = cli.get("hardware.platform")
-            esxi_info['serial_number'] = hardware.Get().SerialNumber
+            esxi_info['serialno_a'] = hardware.Get().SerialNumber
 
 
         # 取机柜名称
@@ -130,7 +133,7 @@ def main(args):
     更新 zabbix 中 Hypervisors 组中 host 的 inventory. 其内容从 vCenter 中获取.
     '''
     zapi = args.zapi
-    
+
     zbx_group = zapi.hostgroup.get({
         'output': ['groupid', 'name'],
         'selectHosts': ['hostid', 'name'],
@@ -142,7 +145,7 @@ def main(args):
 
     grp_hosts = zbx_group[0].get('hosts')
 
-    # 如指定limit参数, 则仅处理列表中的host 
+    # 如指定limit参数, 则仅处理列表中的host
     if args.limit:
         grp_hosts = [h for h in grp_hosts if h['name'] in args.limit]
 
@@ -151,12 +154,15 @@ def main(args):
     hosts = zapi.host.get({
         'output': ['hostid', 'name'],
         'hostids': [h['hostid'] for h in grp_hosts],
-        'selectMacros': ['macro', 'value']
+        'selectMacros': ['macro', 'value'],
+        'selectInventory': 'extend'
     })
 
     for host in hosts:
         host_id = host['hostid']
         host_name = host['name']
+        tags = InventoryTagDict(host['inventory']['tag'])
+        tags['Esxi'] = None
 
         # 从zabbix host的macros 中取出对应的vcenter登录信息
         url = ''.join([ma['value'] for ma in host['macros'] if ma['macro'] == '{$URL}'])
@@ -164,36 +170,18 @@ def main(args):
         vcenter_admin = ''.join([ma['value'] for ma in host['macros'] if ma['macro'] == '{$USERNAME}'])
         vcenter_pwd = ''.join([ma['value'] for ma in host['macros'] if ma['macro'] == '{$PASSWORD}'])
 
-        logging.info(f'[fetch_esxi] vcenter_ip: {vcenter_ip}, esxi_name:{host_name}')
-
         try:
+            logging.info(f'[fetch_esxi] vcenter_ip: {vcenter_ip}, esxi_name:{host_name}')
             esxi_info = fetch_esxi(host=vcenter_ip,
                                    user=vcenter_admin,
                                    pwd=vcenter_pwd,
                                    esxi_name=host_name)
-
-            zapi.host.update({
-                "hostid": host_id,
-                "inventory": {
-                    "type": esxi_info.get('type'),
-                    "name": esxi_info.get('name'),
-                    "alias": esxi_info.get('ip'),
-                    "os": esxi_info.get('os'),
-                    "os_full": esxi_info.get('os_full'),
-                    "os_short": esxi_info.get('os_short'),
-                    "serialno_a": esxi_info.get('serial_number'),
-                    "tag": esxi_info.get('tag'),
-                    "macaddress_a": esxi_info.get('mac_address'),
-                    "macaddress_b": esxi_info.get('mac_address'),
-                    "model": esxi_info.get('model'),
-                    "vendor": esxi_info.get('vendor'),
-                    "host_networks": esxi_info.get('ip'),
-                    "host_netmask": esxi_info.get('subnet_mask'),
-                    "hardware_full": '\n'.join([esxi_info.get('cpu',''), esxi_info.get('mem','')]),
-                    "location": esxi_info.get('location'),
-                    "site_rack": esxi_info.get('site_rack')
-                }
-            })
+ 
+            esxi_info.update({'tag': str(tags)})
+            update_params = {'hostid': host_id, 'inventory': esxi_info}
+            if host['inventory']['inventory_mode'] == '-1':  # disabled
+                update_params['inventory_mode'] = '1'  # Auto
+            zapi.host.update(update_params)
             logging.info(f'update host->{host_name} success!')
 
         except ZabbixAPIException as error:
